
## @knitr loading, results='hide', echo=FALSE, warning=FALSE, message=FALSE
library(SOMbrero)


## @knitr lesmisDescr, fig.width=12, fig.height=12
data(lesmis)
lesmis
plot(lesmis, vertex.size=0)


## @knitr lesmisTrain, cache=TRUE
set.seed(4031719)
mis.som <- trainSOM(x.data=dissim.lesmis, type="relational", nb.save=10)
plot(mis.som, what="energy")


## @knitr lesmisClustering
mis.som$clustering
table(mis.som$clustering)
plot(mis.som)


## @knitr lesmisPseudoNamesPlot, fig.height=12, fig.width=12, warning=FALSE
plot(mis.som, what="obs", type="names")


## @knitr lesmisProjGraph
plot(mis.som, what="add", type="graph", var=lesmis)


## @knitr lesmisProtoProfiles
plot(mis.som, what="prototypes", type="lines")
plot(mis.som, what="prototypes", type="barplot")
plot(mis.som, what="prototypes", type="radar")


## @knitr lesmisProtoDist
plot(mis.som, what="prototypes", type="poly.dist", print.title=TRUE)
plot(mis.som, what="prototypes", type="smooth.dist")
plot(mis.som, what="prototypes", type="umatrix", print.title=TRUE)
plot(mis.som, what="prototypes", type="mds")
plot(mis.som, what="prototypes", type="grid.dist")


## @knitr lesmisColorOverview, fig.height=12, fig.width=12
plot(lesmis, vertex.label.color=rainbow(25)[mis.som$clustering], vertex.size=0)
legend(x="left", legend=1:25, col=rainbow(25), pch=19)


## @knitr lesmisSCOverview
plot(superClass(mis.som))


## @knitr lesmisSC
sc.mis <- superClass(mis.som, k=6)
summary(sc.mis)
table(sc.mis$cluster)
plot(sc.mis)
plot(sc.mis, type="grid", plot.legend=TRUE)
plot(sc.mis, type="lines", print.title=TRUE)
plot(sc.mis, type="mds", plot.legend=TRUE)
plot(sc.mis, type="dendro3d")


## @knitr lesmisSCColorOverview, fig.width=12, fig.height=12
plot(lesmis, vertex.size=0, vertex.label.color=
       brewer.pal(6, "Set2")[sc.mis$cluster[mis.som$clustering]])
legend(x="left", legend=paste("SC",1:6), col=brewer.pal(6, "Set2"), pch=19)


## @knitr irisTrain
# run the numeric SOM
set.seed(4031730)
iris.som <- trainSOM(x.data=iris[,1:4])
# run the relational SOM
iris.dist <- dist(iris[,1:4], method="minkowski", diag=TRUE, upper=TRUE, p=4)
set.seed(7071731)
d.iris.som <- trainSOM(x.data=iris.dist, type="relational")


## @knitr irisPies
plot(iris.som, what="add", type="pie", variable=iris$Species, 
     main="species distribution with 'numeric' SOM")
plot(d.iris.som, what="add", type="pie", variable=iris$Species, 
     main="species distribution with 'relational' SOM")


